function [t,f]=tfscale(fs,N,m,size);
% TFSCALE: time and frequency scales for tfds
% [t,f]=tfscale(fs,block,hop,size)
%	fs:	sampling rate in Hz
%	block:	frame size for FFT - determines frequency resolution
%	hop:		hop size - determines time resolution
%  size:		[height width] of tfd matrix - determines extents

w=size(2);
h=size(1);
t=[0 (w-1)*m/fs];
f=[0 (h-1)*fs/N];

